@@ -79,21 +79,9 @@ void set_exe_path(char *argv0) {
 #ifdef NT	/* CMD.EXE doesn't give us the full path in argv[0] :-( */
 			/* so we need to fix this */
 	{
-		HMODULE mh;
 		char *tpath = NULL;
 		int pl;
 
-		/* Add an .exe extension if it is missing */
-		if (i < 4 || _stricmp(exe_path +i -4, ".exe") != 0)
-			strcat(exe_path, ".exe");
-
-		if ((mh = GetModuleHandle(exe_path)) == NULL) {
-			a1loge(g_log, 1, "set_exe_path: GetModuleHandle '%s' failed with%d\n",
-			                                            exe_path,GetLastError());
-			exe_path[0] = '\000';
-			return;
-		}
-		
 		/* Retry until we don't truncate the returned path */
 		for (pl = 100; ; pl *= 2) {
 			if (tpath != NULL)
@@ -103,7 +91,7 @@ void set_exe_path(char *argv0) {
 				exe_path[0] = '\000';
 			return;
 			}
-			if ((i = GetModuleFileName(mh, tpath, pl)) == 0) {
+			if ((i = GetModuleFileName(NULL, tpath, pl)) == 0) {
 				a1loge(g_log, 1, "set_exe_path: GetModuleFileName '%s' failed with%d\n",
 				                                                tpath,GetLastError());
 				exe_path[0] = '\000';
@@ -125,6 +113,9 @@ void set_exe_path(char *argv0) {
 	}
 #else		/* Neither does UNIX */
 
+	/* Should use readlink("/proc/self/exe", dest, PATH_MAX) on Linux... */
+	/* Should use _NSGetExecutablePath() on OS X */
+
 	if (*exe_path != '/') {			/* Not already absolute */
 		char *p, *cp;
 		if (strchr(exe_path, '/') != 0) {	/* relative path */
@@ -350,11 +341,15 @@ static char *get_sys_info() {
 #ifdef UNIX
 
 static char *get_sys_info() {
-	static char sysinfo[300] = { "Unknown" };
+	static char sysinfo[500] = { "Unknown" };
 	struct utsname ver;
 
 	if (uname(&ver) == 0)
-		sprintf(sysinfo,"%s %s %s %s",ver.sysname, ver.version, ver.release, ver.machine);
+#if defined(__APPLE__)
+		sprintf(sysinfo,"%s, %s, %s, %s (OS X %s)",ver.sysname, ver.version, ver.release, ver.machine, osx_get_version_str());
+#else
+		sprintf(sysinfo,"%s, %s, %s, %s",ver.sysname, ver.version, ver.release, ver.machine);
+#endif
 	return sysinfo;
 }
 
@@ -789,7 +784,7 @@ size_t nsize
 }
 
 /******************************************************************/
-/* OS X App Nap fixes                                             */
+/* OS X support functions                                         */
 /******************************************************************/
 
 #if defined(__APPLE__)
@@ -804,6 +799,144 @@ size_t nsize
 # include <objc/objc-auto.h>
 #endif
 
+#include <CoreFoundation/CFURL.h>
+#include <CoreFoundation/CFStream.h>
+#include <CoreFoundation/CFPropertyList.h>
+
+/* OS X version info. Apple has not maintained any consistent function to do this ! */
+/* (This code is from "Mecki" via stackoverflow) */
+
+static bool osx_versionOK = false;
+static bool osx_onceToken = false;
+static unsigned osx_versions[3] = { 0, 0, 0 };
+static char osx_versions_str[40] = { "0.0.0" };
+
+#if __MAC_OS_X_VERSION_MAX_ALLOWED < 1050
+
+#include <Carbon/Carbon.h>
+
+void initMacOSVersion() {
+    SInt32 vers;
+    SInt32 maj, min, bug;
+
+	osx_onceToken = true;
+
+    Gestalt(gestaltSystemVersion, &vers);
+	maj = vers/0x1000 * 10 + (vers/0x100 % 0x10) ;
+	min = (vers/0x10) % 0x10;
+	bug = (vers) % 0x10;
+
+	osx_versions[0] = maj;
+	osx_versions[1] = min;
+	osx_versions[2] = bug;
+
+	sprintf(osx_versions_str, "%d.%d.%d", maj, min, bug);
+
+	osx_versionOK = true;
+}
+
+#else
+
+#include <CoreFoundation/CFURL.h>
+#include <CoreFoundation/CFStream.h>
+#include <CoreFoundation/CFPropertyList.h>
+
+void initMacOSVersion() {
+	osx_onceToken = true;
+
+	// `Gestalt()` actually gets the system version from this file.
+	// Even `if (@available(macOS 10.x, *))` gets the version from there.
+	CFURLRef url = CFURLCreateWithFileSystemPath(
+		NULL, CFSTR("/System/Library/CoreServices/SystemVersion.plist"),
+		kCFURLPOSIXPathStyle, false);
+	if (!url) return;
+
+	CFReadStreamRef readStr = CFReadStreamCreateWithFile(NULL, url);
+	CFRelease(url);
+	if (!readStr) return;
+
+	if (!CFReadStreamOpen(readStr)) {
+		CFRelease(readStr);
+		return;
+	}
+
+	CFErrorRef outError = NULL;
+	CFPropertyListRef propList = CFPropertyListCreateWithStream(
+		NULL, readStr, 0, kCFPropertyListImmutable, NULL, &outError);
+	CFRelease(readStr);
+	if (!propList) {
+		CFShow(outError);
+		CFRelease(outError);
+		return;
+	}
+
+	if (CFGetTypeID(propList) != CFDictionaryGetTypeID()) {
+		CFRelease(propList);
+		return;
+	}
+
+	CFDictionaryRef dict = propList;
+	CFTypeRef ver = CFDictionaryGetValue(dict, CFSTR("ProductVersion"));
+	if (ver) CFRetain(ver);
+	CFRelease(dict);
+	if (!ver) return;
+
+	if (CFGetTypeID(ver) != CFStringGetTypeID()) {
+		CFRelease(ver);
+		return;
+	}
+
+	CFStringRef verStr = ver;
+	// `1 +` for the terminating NUL (\0) character
+	CFIndex size = 1 + CFStringGetMaximumSizeForEncoding(
+		CFStringGetLength(verStr), kCFStringEncodingASCII);
+	// `calloc` initializes the memory with all zero (all \0)
+	char * cstr = calloc(1, size);
+	if (!cstr) {
+		CFRelease(verStr);
+		return;
+	}
+
+	CFStringGetBytes(ver, CFRangeMake(0, CFStringGetLength(verStr)),
+		kCFStringEncodingASCII, '?', false, (UInt8 *)cstr, size, NULL);
+	CFRelease(verStr);
+
+	int scans = sscanf(cstr, "%u.%u.%u",
+		&osx_versions[0], &osx_versions[1], &osx_versions[2]);
+	free(cstr);
+
+	// There may only be two values, but only one is definitely wrong.
+	// As `version` is `static`, its zero initialized.
+	osx_versionOK = (scans >= 2);
+
+	sprintf(osx_versions_str, "%d.%d.%d", osx_versions[0], osx_versions[1], osx_versions[2]);
+}
+
+#endif
+
+/* Get the OS X version number. */
+/* Return maj + min/100.0 + bugfix/10000.0 */
+/* (Returns 0.0 if unable to get version */
+double osx_get_version() {
+	double rv = 0.0;
+
+	if (!osx_onceToken)
+		initMacOSVersion();
+
+	if (osx_versionOK)
+		rv = osx_versions[0] + osx_versions[1]/100.0 + osx_versions[2]/10000.0;
+
+	return rv;
+}
+
+/* Get text OS X verion number, i.e. "10.3.1" */
+char *osx_get_version_str() {
+	if (!osx_onceToken)
+		initMacOSVersion();
+
+	return osx_versions_str;
+}
+
 /*
 	OS X 10.9+ App Nap problems bug:
 
@@ -4029,8 +4162,11 @@ char *debPdv(int di, double *p) {
 /* Print a float color vector to a string. */
 /* Returned static buffer is re-used every 5 calls. */
 char *debPfv(int di, float *p) {
-	static char buf[DEB_NO_BUFS][DEB_MAX_CHAN * 50];
+#   define BUFSZ (DEB_MAX_CHAN * 50)
+	char *fmt = "%.8f";
+	static char buf[DEB_NO_BUFS][BUFSZ];
 	static int ix = 0;
+	int brem = BUFSZ;
 	int e;
 	char *bp;
 
@@ -4041,15 +4177,18 @@ char *debPfv(int di, float *p) {
 		ix = 0;
 	bp = buf[ix];
 
-	if (di > DEB_MAX_CHAN)
-		di = DEB_MAX_CHAN;		/* Make sure that buf isn't overrun */
-
-	for (e = 0; e < di; e++) {
+	for (e = 0; e < di && brem > 10; e++) {
+		int tt;
 		if (e > 0)
-			*bp++ = ' ';
-		sprintf(bp, "%.8f", p[e]); bp += strlen(bp);
+			*bp++ = ' ', brem--;
+		tt = snprintf(bp, brem, fmt, p[e]);
+		if (tt < 0 || tt >= brem)
+			break;			/* Run out of room... */
+		bp += tt;
+		brem -= tt;
 	}
 	return buf[ix];
+#   undef BUFSZ
 }
 
 /*******************************************/
